@@ -1,7 +1,7 @@
 
 
 import os
-from ebs.linuxnode.gui.kivy.background.mixin import OverlayWindowGuiMixin
+from ebs.linuxnode.gui.kivy.background.mixin import BackgroundMixin
 from .text import FontsGuiMixin
 from .log import LoggingGuiMixin
 from .busy import BusySpinnerGuiMixin
@@ -11,9 +11,9 @@ from .display import DisplayMixin
 
 class BaseIoTNodeGui(NodeIDGuiMixin,
                      BusySpinnerGuiMixin,
+                     BackgroundMixin,
                      LoggingGuiMixin,
                      FontsGuiMixin,
-                     OverlayWindowGuiMixin,
                      DisplayMixin):
 
     def __init__(self, *args, **kwargs):
@@ -27,6 +27,11 @@ class BaseIoTNodeGui(NodeIDGuiMixin,
             os.path.abspath(os.path.dirname(__file__))
         )
 
+    def sysinfo_install(self):
+        super(BaseIoTNodeGui, self).sysinfo_install()
+        self.sysinfo.app.versions.register_package('kivy')
+        self.sysinfo.app.versions.register_namespace('kivy-garden')
+
     def gui_setup(self):
         super(BaseIoTNodeGui, self).gui_setup()
         return self.gui_root
